@@ -940,12 +940,12 @@ impl Index {
                 .0
                 .into_iter()
                 .map(|x| match x {
-                    TensorAxisIndex::Tensor(tensor) => {
-                        TensorAxisIndex::Tensor(tensor.hashed().try_into().unwrap())
-                    }
-                    _ => x,
+                    TensorAxisIndex::Tensor(tensor) => Ok(TensorAxisIndex::Tensor(
+                        tensor.hashed()?.try_into().unwrap(),
+                    )),
+                    _ => Ok(x),
                 })
-                .collect(),
+                .collect::<Result<_>>()?,
         );
 
         index.validate(&node.info().shape)?;
