@@ -16,7 +16,7 @@ use rr_util::{
     py_types::{assert_tensors_close, ExtraPySelfOps, PyShape, Tensor, PY_UTILS},
     pycall, python_error_exception, simple_from,
     tensor_util::{
-        broadcast_shapes, check_canon_idxs, MiscInputError, Shape, TorchDevice, TorchDeviceDtype,
+        broadcast_shapes_impl, check_canon_idxs, MiscInputError, Shape, TorchDeviceDtype,
         TorchDeviceDtypeOp, TorchDtype,
     },
 };
@@ -510,6 +510,39 @@ pub struct GeneralFunctionPowSpec {}
 
 simple_from!(|x: GeneralFunctionPowSpec| -> GeneralFunctionSpec { GeneralFunctionSpec::Pow(x) });
 
+/// NOTE: expanding/batching doesn't nicely handle this (in the way it nicely handles add)
+/// More generally, we have poor general func support for expand/batch
+#[pyfunction(special_case_ones = "true")]
+pub fn get_shape_info_broadcast(
+    shapes: Vec<Shape>,
+    special_case_ones: bool,
+) -> Result<GeneralFunctionShapeInfo> {
+    let shape = broadcast_shapes_impl(&shapes, special_case_ones)?;
+
+    Ok(GeneralFunctionShapeInfo {
+        num_non_batchable_output_dims: shapes
+            .iter()
+            .filter_map(|s| {
+                // only check batching dims
+                (s.len() == shape.len()).then(|| {
+                    s.iter()
+                        .zip(&shape)
+                        .rev()
+                        .enumerate()
+                        .filter_map(|(i, (size, broadcast_size))| {
+                            (size != broadcast_size).then_some(i + 1)
+                        })
+                        .max()
+                        .unwrap_or(0)
+                })
+            })
+            .max()
+            .unwrap_or(0) as u8,
+        input_batchability: shapes.iter().map(|s| s.len() == shape.len()).collect(),
+        shape,
+    })
+}
+
 impl ToPyObject for GeneralFunctionPowSpec {
     fn to_object(&self, py: Python<'_>) -> PyObject {
         self.clone().into_py(py)
@@ -539,12 +572,7 @@ impl SpecTrait for GeneralFunctionPowSpec {
                 expected: 2
             });
         }
-        let shape = broadcast_shapes(&shapes)?;
-        Ok(GeneralFunctionShapeInfo {
-            shape: shape,
-            num_non_batchable_output_dims: 0,
-            input_batchability: vec![true, true],
-        })
+        get_shape_info_broadcast(shapes.to_vec(), true)
     }
 
     fn name(&self) -> &'static str {
