@@ -966,11 +966,11 @@ macro_rules! define_circuit {
             #[pymethods]
             impl PyCircuitBase {
             $(
-                pub fn [<as_ $x:snake>](&self) -> Option<$crate::$x> {
+                pub fn [<maybe_ $x:snake>](&self) -> Option<$crate::$x> {
                     arc_ref_clone(&self).into_op()
                 }
 
-                pub fn [<as_ $x:snake _unwrap>](&self) -> PyResult<$x> {
+                pub fn [<cast_ $x:snake>](&self) -> PyResult<$x> {
                     arc_ref_clone(&self).into_op().ok_or_else(|| {
                         // could use fresh error type if we wanted
                         PyErr::new::<pyo3::exceptions::PyTypeError, _>(format!(
