@@ -234,9 +234,8 @@ impl ModuleSpec {
             .expect("output shape should be right aligned subset of batch shape");
 
         let out = if out_batch_rank < aligned_batch_shape.len() {
-            let extra_batch = aligned_batch_shape.len() - out_batch_rank;
             let spec = RearrangeSpec::prepend_batch_shape(
-                aligned_batch_shape[..extra_batch].iter().cloned().collect(),
+                aligned_batch_shape[..(aligned_batch_shape.len() - out_batch_rank)].into(),
                 out.ndim(),
             )
             .context("rank overflow in module expand")?;
@@ -407,6 +406,7 @@ impl ModuleSpec {
             if let Some(r) = node_mapping.get(&x.info().hash) {
                 Ok((*r).clone())
             } else if let Some(n) = x.info().name && n.contains(&clear_names_str) {
+                // internal name + fixup stuff is necessary to be able to cache expansion shape
                 let name = x.get_autoname().unwrap_or(None);
                 Ok(x.rename(name))
             } else {
