@@ -130,7 +130,7 @@ impl SetSymbolicShape {
 
     #[staticmethod]
     pub fn some_set_neq(node: CircuitRc, shape: OpShape, name: Option<Name>) -> Result<CircuitRc> {
-        assert_eq!(node.ndim(), shape.len());
+        assert_eq!(node.ndim(), shape.len()); // we should probably fix calling from python being able to trigger a panic!
         if shape
             .iter()
             .zip(node.shape())
