@@ -240,8 +240,7 @@ pub fn batch_einsum(einsum: &Einsum, context: &mut OptimizationContext) -> Resul
         einsum.info().name,
     )
     .unwrap();
-    let nested_big =
-        einsum_nest_optimize(&einsum_named_axes, &mut no_memory_limit_context).unwrap();
+    let nested_big = einsum_nest_optimize(&einsum_named_axes, &mut no_memory_limit_context)?;
 
     let mut intermediates_above_mem = vec![];
     visit_circuit_unwrap(nested_big.crc(), |c| {
