@@ -282,7 +282,8 @@ pub fn optimize_circuit(
             compiler_simp(x.clone(), context),
             &mut context.cache.module_removed_unused,
             false,
-            true
+            true,
+            true,
         )),
         10,
         print_timings
