@@ -791,10 +791,10 @@ pub fn deep_optimize_einsums(circ: CircuitRc, context: &mut OptimizationContext)
         &|x: CircuitRc, context: &mut OptimizationContext| match &**x {
             Circuit::Einsum(ein) => {
                 let (result, took) = timed_value!(einsum_nest_optimize(ein, context));
-                if result.is_none() {
+                if result.is_err() {
                     Some(timed!(batch_einsum(ein, context).unwrap()))
                 } else {
-                    let result = result?;
+                    let result = result.ok()?;
                     if context.settings.log_slow_einsums && took.as_millis() > 10 {
                         context.cache.slow_einsum_log.push(ein.get_spec());
                     }
