@@ -256,7 +256,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
     Some(Einsum::new(
         new_args,
         einsum.out_axes.clone(),
-        einsum.name_cloned(),
+        einsum.info().name,
     ))
 }
 
@@ -316,7 +316,7 @@ pub fn add_pull_diags(add: &Add) -> Option<Einsum> {
                 )
             })
             .collect(),
-        add.name_cloned(),
+        add.info().name,
     );
     Some(Einsum::new_diag(new_add, overall_diags, None))
 }
