@@ -18,7 +18,7 @@ pub fn circuit_server_serve(
         let msg_string = String::from_utf8(buf).unwrap();
         println!("got {}", msg_string);
         let thingy = Schedule::deserialize(msg_string, device, &mut tensor_cache).unwrap();
-        let result_tensor = thingy.evaluate(Default::default());
+        let result_tensor = thingy.evaluate(Default::default()).unwrap();
 
         let bytes: Vec<u8> = pycall!(PY_UTILS.tensor_to_bytes, (result_tensor,));
         println!("bytes {:?} len {}", bytes.get(..1), bytes.len());
