@@ -24,7 +24,7 @@ use rr_util::{
     eq_by_big_hash::EqByBigHash,
     impl_both_by_big_hash,
     py_types::PyCallable,
-    python_error_exception, setup_callable, simple_default, simple_from,
+    python_error_exception, setup_callable, setup_wrap, simple_default, simple_from,
     tensor_util::Slice,
     util::{
         arc_ref_clone, arc_unwrap_or_clone, as_sorted, flip_op_result, split_first_take, transpose,
@@ -62,9 +62,7 @@ pub enum IterativeMatcherData {
     Raw(RawIterativeMatcher),
     PyFunc(PyCallable), // NOTE: not PyMatcherFunc
 }
-
-setup_callable!(IterativeMatcher, IterativeMatcherData, IterativeMatcherFromPy, match_iterate(circuit : CircuitRc) -> IterateMatchResults);
-
+setup_callable!(IterativeMatcher, IterativeMatcherData, IterativeMatcherFromPy, match_iterate(circuit : CircuitRc) -> IterateMatchResults,no_py_callable);
 simple_from!(|x: Matcher| -> IterativeMatcher { IterativeMatcherData::Match(x).into() });
 simple_from!(|x: MatcherData| -> IterativeMatcher { Matcher::from(x).into() });
 simple_from!(|x: MatcherFromPyBase| -> IterativeMatcher { Matcher::from(x).into() });
