@@ -13,6 +13,7 @@ use macro_rules_attribute::apply;
 use pyo3::prelude::*;
 use rr_util::{
     cached_method,
+    caching::FastUnboundedCache,
     eq_by_big_hash::EqByBigHash,
     util::{transpose, HashBytes},
 };
@@ -34,8 +35,8 @@ pub struct Updater {
     pub(super) cache_update: bool,
     #[pyo3(get, set)]
     pub(super) default_fancy_validate: bool,
-    pub(super) transform_cache: cached::UnboundCache<HashBytes, CircuitRc>,
-    pub(super) updated_cache: cached::UnboundCache<(HashBytes, IterativeMatcherRc), CircuitRc>,
+    pub(super) transform_cache: FastUnboundedCache<HashBytes, CircuitRc>,
+    pub(super) updated_cache: FastUnboundedCache<(HashBytes, IterativeMatcherRc), CircuitRc>,
     pub(super) validation_getter: Getter,
 }
 
@@ -46,8 +47,8 @@ impl Default for Updater {
             cache_transform: true,
             cache_update: true,
             default_fancy_validate: false,
-            transform_cache: cached::UnboundCache::new(),
-            updated_cache: cached::UnboundCache::new(),
+            transform_cache: FastUnboundedCache::default(),
+            updated_cache: FastUnboundedCache::default(),
             validation_getter: Default::default(),
         }
     }
@@ -184,20 +185,20 @@ impl BoundUpdater {
 pub struct Getter {
     #[pyo3(get, set)]
     pub(super) default_fancy_validate: bool,
-    pub(super) cache: cached::UnboundCache<(HashBytes, IterativeMatcherRc), BTreeSet<CircuitRc>>,
+    pub(super) cache: FastUnboundedCache<(HashBytes, IterativeMatcherRc), BTreeSet<CircuitRc>>,
     pub(super) paths_cache:
-        cached::UnboundCache<(HashBytes, IterativeMatcherRc), BTreeMap<CircuitRc, Vec<CircuitRc>>>,
+        FastUnboundedCache<(HashBytes, IterativeMatcherRc), BTreeMap<CircuitRc, Vec<CircuitRc>>>,
     pub(super) all_paths_cache:
-        cached::UnboundCache<(HashBytes, IterativeMatcherRc), Vec<CircuitLinkedList>>,
+        FastUnboundedCache<(HashBytes, IterativeMatcherRc), Vec<CircuitLinkedList>>,
 }
 
 impl Default for Getter {
     fn default() -> Self {
         Self {
             default_fancy_validate: false,
-            cache: cached::UnboundCache::new(),
-            paths_cache: cached::UnboundCache::new(),
-            all_paths_cache: cached::UnboundCache::new(),
+            cache: FastUnboundedCache::default(),
+            paths_cache: FastUnboundedCache::default(),
+            all_paths_cache: FastUnboundedCache::default(),
         }
     }
 }
@@ -517,24 +518,16 @@ impl BoundGetter {
 }
 
 #[pyclass]
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub struct AnyFound {
-    pub(super) cache: cached::UnboundCache<(HashBytes, IterativeMatcherRc), bool>,
-}
-
-impl Default for AnyFound {
-    fn default() -> Self {
-        Self::new()
-    }
+    pub(super) cache: FastUnboundedCache<(HashBytes, IterativeMatcherRc), bool>,
 }
 
 #[pymethods]
 impl AnyFound {
     #[new]
     pub fn new() -> Self {
-        Self {
-            cache: cached::UnboundCache::new(),
-        }
+        Self::default()
     }
     fn __call__(
         &mut self,
@@ -637,7 +630,7 @@ pub struct Expander {
     #[pyo3(get)]
     pub(super) suffix: Option<String>,
     pub(super) batch_cache:
-        cached::UnboundCache<(HashBytes, Vec<IterativeMatcherRc>, HashBytes), CircuitRc>,
+        FastUnboundedCache<(HashBytes, Vec<IterativeMatcherRc>, HashBytes), CircuitRc>,
     pub(super) validation_getter: Getter,
 }
 
@@ -649,7 +642,7 @@ impl Default for Expander {
             ban_multiple_matches_on_node: false,
             default_fancy_validate: false,
             suffix: None,
-            batch_cache: cached::UnboundCache::new(),
+            batch_cache: FastUnboundedCache::default(),
             validation_getter: Default::default(),
         }
     }
