@@ -1,5 +1,6 @@
 #![feature(let_chains)]
 #![feature(fs_try_exists)]
+#![feature(string_leak)]
 /// reexport
 pub use pyo3;
 pub use uuid;
@@ -14,6 +15,7 @@ pub mod char_tokenizer;
 pub mod compact_data;
 pub mod lazy;
 pub mod lru_cache;
+pub mod name;
 pub mod opt_einsum;
 pub mod py_types;
 pub mod python_callables;
