@@ -2,11 +2,13 @@ use std::{
     cmp::{max, min},
     iter::zip,
     rc::Rc,
+    sync::{Arc, Mutex},
 };
 
-use anyhow::{bail, Result};
+use anyhow::{anyhow, bail, Result};
 use cached::proc_macro::cached;
 use num_bigint::BigUint;
+use once_cell::sync::Lazy;
 /// This file optimizes tensor contraction order, like Python's opt_einsum
 /// It specifies contraction order using rotating id's, like opt_einsum or numpy,
 /// which is kindof awkward but compatible
@@ -221,18 +223,22 @@ pub struct EinsumSpec {
 #[pymethods]
 impl EinsumSpec {
     #[new]
-    fn new(operand_ints: &PyList, out_ints: &PyList, int_sizes: &PyDict) -> PyResult<Self> {
-        let sizes_dict: HashMap<usize, usize> = int_sizes.extract().unwrap();
+    fn new(
+        operand_ints: Vec<Vec<usize>>,
+        out_ints: Vec<usize>,
+        int_sizes: &PyDict,
+    ) -> Result<Self> {
+        let sizes_dict: HashMap<usize, usize> = int_sizes.extract()?;
         let int_sizes = dict_to_list(&sizes_dict, None);
         let result = EinsumSpec {
-            input_ints: operand_ints.extract().unwrap(),
-            output_ints: out_ints.extract().unwrap(),
+            input_ints: operand_ints,
+            output_ints: out_ints,
             int_sizes,
         };
         if result.validate() {
             return Ok(result);
         }
-        Err(PyValueError::new_err("invalid"))
+        bail!("invalid")
     }
     pub fn ints_in_input(&self) -> HashSet<usize> {
         let ints_in_input: HashSet<usize> = self.input_ints.iter().flatten().copied().collect();
@@ -509,11 +515,11 @@ impl EinsumSpec {
         check_outer: Option<bool>,
         mem_cap: Option<usize>,
         hash_map_cap: Option<usize>,
-    ) -> Option<Vec<Vec<usize>>> {
+    ) -> Result<Vec<Vec<usize>>> {
         let hash_map_cap = hash_map_cap.unwrap_or(70);
         let mem_cap = mem_cap.unwrap_or(usize::MAX);
         if self.input_ints.len() == 1 {
-            return Some(vec![vec![0]]);
+            return Ok(vec![vec![0]]);
         }
 
         let tensor_ints: Vec<Vec<usize>> = self.input_ints.clone();
@@ -641,7 +647,7 @@ impl EinsumSpec {
                 }
                 let new_cost_checked = cost_cap.checked_mul(cost_cap_increment);
                 match new_cost_checked {
-                    None => return None,
+                    None => bail!("einsum opt couldn't find solution within cost cap"),
                     Some(x) => cost_cap = x,
                 }
             }
@@ -664,7 +670,7 @@ impl EinsumSpec {
         );
         let result = contraction_ssa_ids_to_recycled(&ssa_result, tensor_ints.len());
         assert!(&result.iter().all(|x| x.len() == 2), "{:?}", &result);
-        Some(result)
+        Ok(result)
     }
 
     pub fn optimize(
@@ -673,7 +679,10 @@ impl EinsumSpec {
         mem_cap: Option<usize>,
         hash_map_cap: Option<usize>,
         dont_contract_subsets_into: Option<Vec<usize>>,
-    ) -> Option<Vec<Vec<usize>>> {
+    ) -> Result<Vec<Vec<usize>>> {
+        if let Some(mx) = self.input_ints.iter().flatten().max() && mx > &63{
+            bail!("rust einsum optimization only supports einsum ints up to 63")
+        }
         let (mut result, new_input_ints) =
             self.optimize_pre_contract_subsets(dont_contract_subsets_into);
         // this is ugly, todo fix
@@ -692,7 +701,7 @@ impl EinsumSpec {
             };
             result.extend(new_spec.optimize_dp(check_outer, mem_cap, hash_map_cap)?);
         }
-        Some(result)
+        Ok(result)
     }
 
     fn __repr__(&self) -> String {
@@ -728,19 +737,46 @@ impl EinsumSpec {
     }
 }
 
+static OPT_EINSUM_CACHE: Lazy<
+    Mutex<
+        HashMap<
+            (
+                EinsumSpec,
+                Option<bool>,
+                Option<usize>,
+                Option<usize>,
+                Option<Vec<usize>>,
+            ),
+            Vec<Vec<usize>>,
+        >,
+    >,
+> = Lazy::new(|| Mutex::new(HashMap::default()));
 #[pyfunction]
-#[cached]
 pub fn optimize_einsum_spec_cached(
     spec: EinsumSpec,
     check_outer: Option<bool>,
     mem_cap: Option<usize>,
     hash_map_cap: Option<usize>,
     dont_contract_subsets_into: Option<Vec<usize>>,
-) -> Option<Vec<Vec<usize>>> {
-    spec.optimize(
+) -> Result<Vec<Vec<usize>>> {
+    let key = (
+        spec.clone(),
+        check_outer.clone(),
+        mem_cap.clone(),
+        hash_map_cap.clone(),
+        dont_contract_subsets_into.clone(),
+    );
+    if let Some(r) = OPT_EINSUM_CACHE.lock().unwrap().get(&key) {
+        return Ok(r.clone());
+    }
+    let result = spec.optimize(
         check_outer,
         mem_cap,
         hash_map_cap,
         dont_contract_subsets_into,
-    )
+    );
+    if let Ok(r) = &result {
+        OPT_EINSUM_CACHE.lock().unwrap().insert(key, r.clone());
+    }
+    result
 }
