@@ -25,7 +25,7 @@ const SECTIONS: [usize; 3] = [4, 4, 56];
 const SECTION_STARTS: [usize; 3] = [0, 4, 8];
 
 pub fn get_tensor_hash_parts(tensor: &Tensor) -> Vec<String> {
-    let b16 = encode_lower(&tensor.hashed().hash().unwrap());
+    let b16 = encode_lower(&tensor.hashed().unwrap().hash().unwrap());
     zip(&SECTION_STARTS, &SECTIONS)
         .map(|(a, b)| b16[*a..*a + *b].to_owned())
         .collect()
@@ -183,7 +183,7 @@ pub fn save_tensor(tensor: Tensor, force: bool) -> Result<bool> {
     if force{
         write_tensor_to_dir_tree(&get_rrfs_tensor_db_dir(), tensor.clone(), force)?;
     }else if let Ok(did_write) = result && did_write{
-        register_tensor_unsynced(&tensor.hashed().hash_base16().unwrap())?;
+        register_tensor_unsynced(&tensor.hashed()?.hash_base16().unwrap())?;
     }
     result
 }
