@@ -747,7 +747,7 @@ impl TensorIndex {
                     hasher.update(&i.to_le_bytes());
                 }
                 TensorAxisIndex::Tensor(t) => {
-                    hasher.update(t.hashed().hash().unwrap());
+                    hasher.update(t.hashed().unwrap().hash().unwrap());
                 } // dont bother to check tensor, if you want that canon first
                 TensorAxisIndex::Slice(sl) => sl.update_hash(&mut hasher),
             }
